@@ -12,14 +12,8 @@ See `the FlickrAPI homepage`_ for more info.
 """
 from __future__ import unicode_literals
 
-__version__ = '2.2.1'
-__all__ = ('FlickrAPI', 'IllegalArgumentException', 'FlickrError',
-    'CancelUpload', 'LockingError', 'XMLNode', 'set_log_level', '__version__',
-    'SimpleCache', 'TokenCache', 'SimpleTokenCache', 'LockingTokenCache')
-__author__ = 'Sybren Stüvel'
-
-# Copyright (c) 2007 by the respective coders, see
-# http://www.stuvel.eu/projects/flickrapi
+# Copyright (c) 2007-2017 by the respective coders, see
+# http://stuvel.eu/flickrapi
 #
 # This code is subject to the Python licence, as can be read on
 # http://www.python.org/download/releases/2.5.2/license/
@@ -46,17 +40,21 @@ __author__ = 'Sybren Stüvel'
 # TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-import logging
-
 # Import the core functionality into the flickrapi namespace
 from flickrapi.core import FlickrAPI
 
 from flickrapi.xmlnode import XMLNode
 from flickrapi.exceptions import IllegalArgumentException, \
-        FlickrError, CancelUpload, LockingError
+    FlickrError, CancelUpload, LockingError
 from flickrapi.cache import SimpleCache
 from flickrapi.tokencache import OAuthTokenCache, TokenCache, SimpleTokenCache, \
-        LockingTokenCache
+    LockingTokenCache
+
+__version__ = '2.2.1'
+__all__ = ('FlickrAPI', 'IllegalArgumentException', 'FlickrError',
+           'CancelUpload', 'LockingError', 'XMLNode', 'set_log_level', '__version__',
+           'SimpleCache', 'TokenCache', 'SimpleTokenCache', 'LockingTokenCache')
+__author__ = 'Sybren Stüvel'
 
 
 def set_log_level(level):
@@ -69,15 +67,14 @@ def set_log_level(level):
 
     import flickrapi.core
     import flickrapi.tokencache
-    import flickrapi.contrib
 
     flickrapi.core.LOG.setLevel(level)
     flickrapi.tokencache.LOG.setLevel(level)
-    flickrapi.contrib.LOG.setLevel(level)
 
 
 if __name__ == "__main__":
     print("Running doctests")
     import doctest
+
     doctest.testmod()
     print("Tests OK")
